Documentation
¶
Index ¶
- Constants
- Variables
- func CustomConfigTempalte() string
- func DefaultConfig() (string, interface{})
- func ObservabilityViews() (views []*view.View)
- func RegisterSwaggerAPI(_ client.Context, rtr *mux.Router)
- func SigVerificationGasConsumer(meter sdk.GasMeter, sig signing.SignatureV2, params authtypes.Params) error
- type CustomAppConfig
- type Uptick
- func (app *Uptick) AppCodec() codec.Codec
- func (app *Uptick) BeginBlocker(ctx sdk.Context, req abci.RequestBeginBlock) abci.ResponseBeginBlock
- func (app *Uptick) BlockedAddrs() map[string]bool
- func (app *Uptick) BlockedModuleAccountAddrs() map[string]bool
- func (app *Uptick) DeliverTx(req abci.RequestDeliverTx) (res abci.ResponseDeliverTx)
- func (app *Uptick) EndBlocker(ctx sdk.Context, req abci.RequestEndBlock) abci.ResponseEndBlock
- func (app *Uptick) ExportAppStateAndValidators(forZeroHeight bool, jailAllowedAddrs []string, modulesToExport []string) (servertypes.ExportedApp, error)
- func (app *Uptick) GetBaseApp() *baseapp.BaseApp
- func (app *Uptick) GetIBCKeeper() *ibckeeper.Keeper
- func (app *Uptick) GetKey(storeKey string) *storetypes.KVStoreKey
- func (app *Uptick) GetMemKey(storeKey string) *storetypes.MemoryStoreKey
- func (app *Uptick) GetScopedIBCKeeper() capabilitykeeper.ScopedKeeper
- func (app *Uptick) GetStakingKeeper() stakingkeeper.Keeper
- func (app *Uptick) GetSubspace(moduleName string) paramstypes.Subspace
- func (app *Uptick) GetTKey(storeKey string) *storetypes.TransientStoreKey
- func (app *Uptick) GetTxConfig() client.TxConfig
- func (app *Uptick) InitChainer(ctx sdk.Context, req abci.RequestInitChain) abci.ResponseInitChain
- func (app *Uptick) InterfaceRegistry() types.InterfaceRegistry
- func (app *Uptick) LegacyAmino() *codec.LegacyAmino
- func (app *Uptick) LoadHeight(height int64) error
- func (app *Uptick) ModuleAccountAddrs() map[string]bool
- func (app *Uptick) Name() string
- func (app *Uptick) RegisterAPIRoutes(apiSvr *api.Server, apiConfig config.APIConfig)
- func (app *Uptick) RegisterNodeService(clientCtx client.Context)
- func (app *Uptick) RegisterTendermintService(clientCtx client.Context)
- func (app *Uptick) RegisterTxService(clientCtx client.Context)
- func (app *Uptick) SimulationManager() *module.SimulationManager
- type WasmConfig
Constants ¶
const ( // Name defines the application binary name Name = "uptickd" // ProposalsEnabled If EnabledSpecificProposals is "", and this is "true", then enable all x/wasm proposals. // If EnabledSpecificProposals is "", and this is not "true", then disable all x/wasm proposals. ProposalsEnabled = "true" // EnableSpecificProposals If set to non-empty string it must be comma-separated list of values that are all a subset // of "EnableAllProposals" (takes precedence over ProposalsEnabled) // https://github.com/CosmWasm/wasmd/blob/02a54d33ff2c064f3539ae12d75d027d9c665f05/x/wasm/internal/types/proposal.go#L28-L34 EnableSpecificProposals = "" )
Variables ¶
var ( // DefaultNodeHome default home directories for the application daemon DefaultNodeHome string // ModuleBasics defines the module BasicManager is in charge of setting up basic, // non-dependant module elements, such as codec registration // and genesis verification. ModuleBasics = module.NewBasicManager( auth.AppModuleBasic{}, genutil.AppModuleBasic{}, bank.AppModuleBasic{}, capability.AppModuleBasic{}, staking.AppModuleBasic{}, mint.AppModuleBasic{}, distr.AppModuleBasic{}, gov.NewAppModuleBasic( []govclient.ProposalHandler{ paramsclient.ProposalHandler, upgradeclient.LegacyProposalHandler, upgradeclient.LegacyCancelProposalHandler, ibcclientclient.UpdateClientProposalHandler, ibcclientclient.UpgradeProposalHandler, erc20client.RegisterCoinProposalHandler, erc20client.RegisterERC20ProposalHandler, erc20client.ToggleTokenRelayProposalHandler, }, ), params.AppModuleBasic{}, crisis.AppModuleBasic{}, slashing.AppModuleBasic{}, ibc.AppModuleBasic{}, ibctm.AppModuleBasic{}, authzmodule.AppModuleBasic{}, feegrantmodule.AppModuleBasic{}, upgrade.AppModuleBasic{}, evidence.AppModuleBasic{}, transfer.AppModuleBasic{}, vesting.AppModuleBasic{}, evm.AppModuleBasic{}, feemarket.AppModuleBasic{}, erc20.AppModuleBasic{}, erc721.AppModuleBasic{}, nftmodule.AppModuleBasic{}, nfttransfer.AppModuleBasic{}, wasm.AppModuleBasic{}, ica.AppModuleBasic{}, consensus.AppModuleBasic{}, ) )
Functions ¶
func CustomConfigTempalte ¶ added in v0.2.16
func CustomConfigTempalte() string
func DefaultConfig ¶ added in v0.2.16
func DefaultConfig() (string, interface{})
func ObservabilityViews ¶
func RegisterSwaggerAPI ¶
RegisterSwaggerAPI registers swagger route with API Server
func SigVerificationGasConsumer ¶
func SigVerificationGasConsumer( meter sdk.GasMeter, sig signing.SignatureV2, params authtypes.Params, ) error
SigVerificationGasConsumer is the Uptick implementation of SignatureVerificationGasConsumer. It consumes gas for signature verification based upon the public key type. The cost is fetched from the given params and is matched by the concrete type. The types of keys supported are:
- ethsecp256k1 (Ethereum keys)
- ed25519 (Validators)
- multisig (Cosmos SDK multisigs)
Types ¶
type CustomAppConfig ¶ added in v0.2.16
type CustomAppConfig struct {
serverconfig.Config
WASM WasmConfig `mapstructure:"wasm"`
}
CustomAppConfig defines the configuration for the Nois app.
type Uptick ¶
type Uptick struct {
*baseapp.BaseApp
// keepers
AccountKeeper authkeeper.AccountKeeper
BankKeeper bankkeeper.Keeper
CapabilityKeeper *capabilitykeeper.Keeper
StakingKeeper stakingkeeper.Keeper
SlashingKeeper slashingkeeper.Keeper
MintKeeper mintkeeper.Keeper
DistrKeeper distrkeeper.Keeper
GovKeeper govkeeper.Keeper
CrisisKeeper crisiskeeper.Keeper
UpgradeKeeper upgradekeeper.Keeper
ParamsKeeper paramskeeper.Keeper
IBCKeeper *ibckeeper.Keeper // IBC Keeper must be a pointer in the app, so we can SetRouter on it correctly
EvidenceKeeper evidencekeeper.Keeper
TransferKeeper ibctransferkeeper.Keeper
FeeGrantKeeper feegrantkeeper.Keeper
ICAHostKeeper icahostkeeper.Keeper
// make scoped keepers public for test purposes
ScopedIBCKeeper capabilitykeeper.ScopedKeeper
ScopedTransferKeeper capabilitykeeper.ScopedKeeper
ScopedICAControllerKeeper capabilitykeeper.ScopedKeeper
ScopedICAHostKeeper capabilitykeeper.ScopedKeeper
ScopedNFTTransferKeeper capabilitykeeper.ScopedKeeper
IBCNFTTransferKeeper ibcnfttransferkeeper.Keeper
ConsensusParamsKeeper consensusparamkeeper.Keeper
AuthzKeeper authzkeeper.Keeper
// Ethermint keepers
EvmKeeper *evmkeeper.Keeper
FeeMarketKeeper feemarketkeeper.Keeper
// Uptick keepers
Erc20Keeper *erc20keeper.Keeper
Erc721Keeper erc721keeper.Keeper
NFTKeeper nftkeeper.Keeper
// contains filtered or unexported fields
}
Uptick implements an extended ABCI application. It is an application that may process transactions through Ethereum's EVM running atop of Tendermint consensus.
func NewUptick ¶
func NewUptick( logger log.Logger, db dbm.DB, traceStore io.Writer, loadLatest bool, skipUpgradeHeights map[int64]bool, homePath string, invCheckPeriod uint, encodingConfig simappparams.EncodingConfig, appOpts servertypes.AppOptions, wasmOpts []wasm.Option, baseAppOptions ...func(*baseapp.BaseApp), ) *Uptick
NewUptick returns a reference to a new initialized Ethermint application.
func (*Uptick) AppCodec ¶
AppCodec returns Uptick's app codec.
NOTE: This is solely to be used for testing purposes as it may be desirable for modules to register their own custom testing types.
func (*Uptick) BeginBlocker ¶
func (app *Uptick) BeginBlocker(ctx sdk.Context, req abci.RequestBeginBlock) abci.ResponseBeginBlock
BeginBlocker updates every begin block
func (*Uptick) BlockedAddrs ¶
BlockedAddrs returns all the app's module account addresses that are not allowed to receive external tokens.
func (*Uptick) BlockedModuleAccountAddrs ¶ added in v0.2.16
BlockedModuleAccountAddrs returns all the app's blocked module account addresses.
func (*Uptick) DeliverTx ¶
func (app *Uptick) DeliverTx(req abci.RequestDeliverTx) (res abci.ResponseDeliverTx)
func (*Uptick) EndBlocker ¶
func (app *Uptick) EndBlocker(ctx sdk.Context, req abci.RequestEndBlock) abci.ResponseEndBlock
EndBlocker updates every end block
func (*Uptick) ExportAppStateAndValidators ¶
func (app *Uptick) ExportAppStateAndValidators( forZeroHeight bool, jailAllowedAddrs []string, modulesToExport []string, ) (servertypes.ExportedApp, error)
ExportAppStateAndValidators exports the state of the application for a genesis file.
func (*Uptick) GetBaseApp ¶
GetBaseApp implements the TestingApp interface.
func (*Uptick) GetIBCKeeper ¶
GetIBCKeeper implements the TestingApp interface.
func (*Uptick) GetKey ¶
func (app *Uptick) GetKey(storeKey string) *storetypes.KVStoreKey
GetKey returns the KVStoreKey for the provided store key.
NOTE: This is solely to be used for testing purposes.
func (*Uptick) GetMemKey ¶
func (app *Uptick) GetMemKey(storeKey string) *storetypes.MemoryStoreKey
GetMemKey returns the MemStoreKey for the provided mem key.
NOTE: This is solely used for testing purposes.
func (*Uptick) GetScopedIBCKeeper ¶
func (app *Uptick) GetScopedIBCKeeper() capabilitykeeper.ScopedKeeper
GetScopedIBCKeeper implements the TestingApp interface.
func (*Uptick) GetStakingKeeper ¶
func (app *Uptick) GetStakingKeeper() stakingkeeper.Keeper
GetStakingKeeper implements the TestingApp interface.
func (*Uptick) GetSubspace ¶
func (app *Uptick) GetSubspace(moduleName string) paramstypes.Subspace
GetSubspace returns a param subspace for a given module name.
NOTE: This is solely to be used for testing purposes.
func (*Uptick) GetTKey ¶
func (app *Uptick) GetTKey(storeKey string) *storetypes.TransientStoreKey
GetTKey returns the TransientStoreKey for the provided store key.
NOTE: This is solely to be used for testing purposes.
func (*Uptick) GetTxConfig ¶
GetTxConfig implements the TestingApp interface.
func (*Uptick) InitChainer ¶
func (app *Uptick) InitChainer(ctx sdk.Context, req abci.RequestInitChain) abci.ResponseInitChain
InitChainer updates at chain initialization
func (*Uptick) InterfaceRegistry ¶
func (app *Uptick) InterfaceRegistry() types.InterfaceRegistry
InterfaceRegistry returns Uptick's InterfaceRegistry
func (*Uptick) LegacyAmino ¶
func (app *Uptick) LegacyAmino() *codec.LegacyAmino
LegacyAmino returns Uptick's amino codec.
NOTE: This is solely to be used for testing purposes as it may be desirable for modules to register their own custom testing types.
func (*Uptick) LoadHeight ¶
LoadHeight loads state at a particular height
func (*Uptick) ModuleAccountAddrs ¶
ModuleAccountAddrs returns all the app's module account addresses.
func (*Uptick) RegisterAPIRoutes ¶
RegisterAPIRoutes registers all application module routes with the provided API server.
func (*Uptick) RegisterNodeService ¶ added in v0.2.16
RegisterNodeService registers the node gRPC service on the provided
func (*Uptick) RegisterTendermintService ¶
RegisterTendermintService implements the Application.RegisterTendermintService method.
func (*Uptick) RegisterTxService ¶
func (*Uptick) SimulationManager ¶
func (app *Uptick) SimulationManager() *module.SimulationManager
SimulationManager implements the SimulationApp interface
type WasmConfig ¶ added in v0.2.16
type WasmConfig struct {
// SimulationGasLimit is the max gas that can be spent when executing a simulation TX.
SimulationGasLimit uint64 `mapstructure:"simulation_gas_limit"`
// QueryGasLimit is the maximum sdk gas (wasm and storage) that we allow for any x/wasm "smart" queries
QueryGasLimit uint64 `mapstructure:"query_gas_limit"`
// MemoryCacheSize defines the memory size for Wasm modules that we can keep cached to speed-up instantiation
// The value is in MiB not bytes
MemoryCacheSize uint64 `mapstructure:"memory_cache_size"`
}
Directories
¶
| Path | Synopsis |
|---|---|
|
Package ante defines the SDK auth module's AnteHandler as well as an internal AnteHandler for an Ethereum transaction (i.e MsgEthereumTx).
|
Package ante defines the SDK auth module's AnteHandler as well as an internal AnteHandler for an Ethereum transaction (i.e MsgEthereumTx). |